@@ -6,7 +6,7 @@ if sys.version_info < (3, 10):
 else:
     from importlib.metadata import entry_points
 
-__version__ = "0.0.2"
+__version__ = "0.0.3"
 
 class OutputType(Enum):
     SRD_OUTPUT_ANN = 0
@@ -68,7 +68,7 @@ class Decoder:
         if not hasattr(self, "decoder_channel_to_data_channel"):
             self.decoder_channel_to_data_channel = {}
             self.one_to_one = True
-        optional = []
+        optional = tuple()
         if hasattr(self, "optional_channels"):
             optional = self.optional_channels
         for i, c in enumerate(self.channels + optional):
